@@ -29,7 +29,7 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include "algorithms/StatFactory.h"
 
 namespace crule{
-  enum CRULE_TYPE {overwrite=0, maxndvi=1, maxband=2, minband=3, validband=4, mean=5, mode=6, median=7,sum=8};
+  enum CRULE_TYPE {overwrite=0, maxndvi=1, maxband=2, minband=3, validband=4, mean=5, mode=6, median=7,sum=8,minallbands=9,maxallbands=10};
 }
 
 using namespace std;
@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
   Optionpk<double>  uly_opt("uly", "uly", "Upper left y value bounding box", 0.0);
   Optionpk<double>  lrx_opt("lrx", "lrx", "Lower right x value bounding box", 0.0);
   Optionpk<double>  lry_opt("lry", "lry", "Lower right y value bounding box", 0.0);
-  Optionpk<string> crule_opt("cr", "crule", "Composite rule (overwrite, maxndvi, maxband, minband, mean, mode (only for byte images), median, sum", "overwrite");
+  Optionpk<string> crule_opt("cr", "crule", "Composite rule (overwrite, maxndvi, maxband, minband, mean, mode (only for byte images), median, sum, maxallbands, minallbands", "overwrite");
   Optionpk<int> ruleBand_opt("cb", "cband", "band index used for the composite rule (e.g., for ndvi, use --cband=0 --cband=1 with 0 and 1 indices for red and nir band respectively", 0);
   Optionpk<double> srcnodata_opt("srcnodata", "srcnodata", "invalid value for input image", 0);
   Optionpk<int> bndnodata_opt("bndnodata", "bndnodata", "Bands in input image to check if pixel is valid (used for srcnodata, min and max options)", 0);
@@ -63,7 +63,14 @@ int main(int argc, char *argv[])
   Optionpk<short> class_opt("c", "class", "classes for multi-band output image: each band represents the number of observations for one specific class. Use value 0 for no multi-band output image.", 0);
   Optionpk<string>  colorTable_opt("ct", "ct", "color table file with 5 columns: id R G B ALFA (0: transparent, 255: solid)");
   Optionpk<string>  description_opt("d", "description", "Set image description");
-  Optionpk<bool>  verbose_opt("v", "verbose", "verbose", false);
+  Optionpk<bool>  verbose_opt("v", "verbose", "verbose", false,2);
+
+  file_opt.setHide(1);
+  weight_opt.setHide(1);
+  class_opt.setHide(1);
+  colorTable_opt.setHide(1);
+  description_opt.setHide(1);
+  verbose_opt.setHide(1);
 
   bool doProcess;//stop process when program was invoked with help option (-h --help)
   try{
@@ -101,6 +108,9 @@ int main(int argc, char *argv[])
     exit(0);
   }
   if(!doProcess){
+    cout << endl;
+    cout << "Usage: pkcomposite -i input [-i input]* -o output" << endl;
+    cout << endl;
     std::cout << "short option -h shows basic options only, use long option --help to show all options" << std::endl;
     exit(0);//help was invoked, stop processing
   }
@@ -118,6 +128,8 @@ int main(int argc, char *argv[])
   cruleMap["mode"]=crule::mode;
   cruleMap["median"]=crule::median;
   cruleMap["sum"]=crule::sum;
+  cruleMap["maxallbands"]=crule::maxallbands;
+  cruleMap["minallbands"]=crule::minallbands;
 
   while(srcnodata_opt.size()<bndnodata_opt.size())
     srcnodata_opt.push_back(srcnodata_opt[0]);
@@ -264,6 +276,12 @@ int main(int argc, char *argv[])
         case(crule::sum):
           cout << "Composite rule: sum" << endl;
           break;
+        case(crule::minallbands):
+          cout << "Composite rule: minallbands" << endl;
+          break;
+        case(crule::maxallbands):
+          cout << "Composite rule: maxallbands" << endl;
+          break;
         }
       }
       if(band_opt.size()){
@@ -459,7 +477,7 @@ int main(int argc, char *argv[])
     Vector2d< vector<double> > storeBuffer;
     vector<bool> writeValid(ncol);
 
-    if(cruleMap[crule_opt[0]]==crule::mean||cruleMap[crule_opt[0]]==crule::median||cruleMap[crule_opt[0]]==crule::sum)//mean, median or (weighted) sum value
+    if(cruleMap[crule_opt[0]]==crule::mean||cruleMap[crule_opt[0]]==crule::median||cruleMap[crule_opt[0]]==crule::sum||cruleMap[crule_opt[0]]==crule::minallbands||cruleMap[crule_opt[0]]==crule::maxallbands)//mean, median, (weighted) sum value, minallbands, maxallbands
       storeBuffer.resize(nband,ncol);
     for(int icol=0;icol<imgWriter.nrOfCol();++icol){
       writeValid[icol]=false;
@@ -720,6 +738,8 @@ int main(int argc, char *argv[])
             case(crule::mean)://mean value
 	    case(crule::median)://median value
 	    case(crule::sum)://sum value
+	    case(crule::minallbands)://minimum for each and every band
+	    case(crule::maxallbands)://maximum for each and every band
               switch(theResample){
               case(BILINEAR):
                 lowerCol=readCol-0.5;
@@ -781,7 +801,7 @@ int main(int argc, char *argv[])
             ++fileBuffer[ib];
             break;
 	    }
-          }
+	  }
 	  else{
             writeValid[ib]=true;//readValid was true
             int iband=0;
@@ -789,6 +809,8 @@ int main(int argc, char *argv[])
             case(crule::mean):
             case(crule::median):
             case(crule::sum):
+            case(crule::minallbands):
+            case(crule::maxallbands):
               switch(theResample){
               case(BILINEAR):
                 lowerCol=readCol-0.5;
@@ -932,6 +954,16 @@ int main(int argc, char *argv[])
             if(storeBuffer[bands[iband]][icol].size())
               writeBuffer[iband][icol]=stat.sum(storeBuffer[bands[iband]][icol]);
             break;
+          case(crule::minallbands):
+            assert(storeBuffer[bands[iband]][icol].size()==fileBuffer[icol]);
+            if(storeBuffer[bands[iband]][icol].size())
+              writeBuffer[iband][icol]=stat.mymin(storeBuffer[bands[iband]][icol]);
+            break;
+          case(crule::maxallbands):
+            assert(storeBuffer[bands[iband]][icol].size()==fileBuffer[icol]);
+            if(storeBuffer[bands[iband]][icol].size())
+              writeBuffer[iband][icol]=stat.mymax(storeBuffer[bands[iband]][icol]);
+            break;
           default:
             break;
           }
