@@ -32,26 +32,37 @@ int main(int argc, char *argv[])
   Optionpk<string> input_opt("i", "input", "Input raster dataset.");
   Optionpk<string> reference_opt("ref", "reference", "Reference (raster or vector) dataset");
   Optionpk<string> layer_opt("ln", "ln", "Layer name(s) in sample. Leave empty to select all (for vector reference datasets only)");
-  Optionpk<string> output_opt("o", "output", "Output dataset (optional)");
-  Optionpk<string> ogrformat_opt("f", "f", "OGR format for output vector (for vector reference datasets only)","SQLite");
   Optionpk<string> mask_opt("m", "mask", "Use the first band of the specified file as a validity mask. Nodata values can be set with the option msknodata.");
-  Optionpk<int> masknodata_opt("msknodata", "msknodata", "Mask value(s) where image is invalid. Use negative value for valid data (example: use -t -1: if only -1 is valid value)", 0);
-  Optionpk<short> valueE_opt("\0", "correct", "Value for correct pixels", 0,2);
-  Optionpk<short> valueO_opt("\0", "omission", "Value for omission errors: input label > reference label", 1,2);
-  Optionpk<short> valueC_opt("\0", "commission", "Value for commission errors: input label < reference label", 2,1);
+  Optionpk<double> msknodata_opt("msknodata", "msknodata", "Mask value(s) where image is invalid. Use negative value for valid data (example: use -t -1: if only -1 is valid value)", 0);
   Optionpk<short> nodata_opt("nodata", "nodata", "No data value(s) in input or reference dataset are ignored");
-  Optionpk<short> band_opt("b", "band", "Input raster band", 0);
+  Optionpk<short> band_opt("b", "band", "Input (reference) raster band. Optionally, you can define different bands for input and reference bands respectively: -b 1 -b 0.", 0);
+  Optionpk<bool> rmse_opt("rmse", "rmse", "Report root mean squared error", false);
+  Optionpk<bool> regression_opt("reg", "reg", "Report linear regression (Input = c0+c1*Reference)", false);
   Optionpk<bool> confusion_opt("cm", "confusion", "Create confusion matrix (to std out)", false);
   Optionpk<string> labelref_opt("lr", "lref", "Attribute name of the reference label (for vector reference datasets only)", "label");
+  Optionpk<string> classname_opt("c", "class", "List of class names."); 
+  Optionpk<short> classvalue_opt("r", "reclass", "List of class values (use same order as in classname option)."); 
+  Optionpk<string> output_opt("o", "output", "Output dataset (optional)");
+  Optionpk<string> ogrformat_opt("f", "f", "OGR format for output vector (for vector reference datasets only)","SQLite");
   Optionpk<string> labelclass_opt("lc", "lclass", "Attribute name of the classified label (for vector reference datasets only)", "class");
   Optionpk<short> boundary_opt("bnd", "boundary", "Boundary for selecting the sample (for vector reference datasets only)", 1,1);
   Optionpk<bool> homogeneous_opt("hom", "homogeneous", "Only take regions with homogeneous boundary into account (for reference datasets only)", false,1);
   Optionpk<bool> disc_opt("circ", "circular", "Use circular boundary (for vector reference datasets only)", false,1);
-  Optionpk<string> classname_opt("c", "class", "List of class names."); 
-  Optionpk<short> classvalue_opt("r", "reclass", "List of class values (use same order as in classname option)."); 
   Optionpk<string> colorTable_opt("ct", "ct", "Color table in ASCII format having 5 columns: id R G B ALFA (0: transparent, 255: solid).");
   Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
-  Optionpk<short> verbose_opt("v", "verbose", "Verbose level", 0);
+  Optionpk<short> valueE_opt("\0", "correct", "Value for correct pixels", 0,2);
+  Optionpk<short> valueO_opt("\0", "omission", "Value for omission errors: input label > reference label", 1,2);
+  Optionpk<short> valueC_opt("\0", "commission", "Value for commission errors: input label < reference label", 2,1);
+  Optionpk<short> verbose_opt("v", "verbose", "Verbose level", 0,2);
+
+  output_opt.setHide(1);
+  ogrformat_opt.setHide(1);
+  labelclass_opt.setHide(1);
+  boundary_opt.setHide(1);
+  homogeneous_opt.setHide(1);
+  disc_opt.setHide(1);
+  colorTable_opt.setHide(1);
+  option_opt.setHide(1);
 
   bool doProcess;//stop process when program was invoked with help option (-h --help)
   try{
@@ -59,25 +70,27 @@ int main(int argc, char *argv[])
     reference_opt.retrieveOption(argc,argv);
     layer_opt.retrieveOption(argc,argv);
     band_opt.retrieveOption(argc,argv);
+    rmse_opt.retrieveOption(argc,argv);
+    regression_opt.retrieveOption(argc,argv);
     confusion_opt.retrieveOption(argc,argv);
     labelref_opt.retrieveOption(argc,argv);
     classname_opt.retrieveOption(argc,argv);
     classvalue_opt.retrieveOption(argc,argv);
     nodata_opt.retrieveOption(argc,argv);
     mask_opt.retrieveOption(argc,argv);
-    masknodata_opt.retrieveOption(argc,argv);
+    msknodata_opt.retrieveOption(argc,argv);
     output_opt.retrieveOption(argc,argv);
     ogrformat_opt.retrieveOption(argc,argv);
     labelclass_opt.retrieveOption(argc,argv);
-    valueE_opt.retrieveOption(argc,argv);
-    valueO_opt.retrieveOption(argc,argv);
-    valueC_opt.retrieveOption(argc,argv);
     boundary_opt.retrieveOption(argc,argv);
     homogeneous_opt.retrieveOption(argc,argv);
     disc_opt.retrieveOption(argc,argv);
     colorTable_opt.retrieveOption(argc,argv);
     option_opt.retrieveOption(argc,argv);
     // class_opt.retrieveOption(argc,argv);
+    valueE_opt.retrieveOption(argc,argv);
+    valueO_opt.retrieveOption(argc,argv);
+    valueC_opt.retrieveOption(argc,argv);
     verbose_opt.retrieveOption(argc,argv);
   }
   catch(string predefinedString){
@@ -85,6 +98,9 @@ int main(int argc, char *argv[])
     exit(0);
   }
   if(!doProcess){
+    cout << endl;
+    cout << "Usage: pkdiff -i input -ref reference" << endl;
+    cout << endl;
     std::cout << "short option -h shows basic options only, use long option --help to show all options" << std::endl;
     exit(0);//help was invoked, stop processing
   }
@@ -108,6 +124,11 @@ int main(int argc, char *argv[])
     exit(0);
   }
 
+  //band_opt[0] is for input
+  //band_opt[1] is for reference
+  if(band_opt.size()<2)
+    band_opt.push_back(band_opt[0]);
+
   if(mask_opt.size())
     while(mask_opt.size()<input_opt.size())
       mask_opt.push_back(mask_opt[0]);
@@ -118,6 +139,14 @@ int main(int argc, char *argv[])
   map<string,short> classValueMap;
   vector<std::string> nameVector(255);//the inverse of the classValueMap
   vector<string> classNames;
+
+  unsigned int ntotalValidation=0;
+  unsigned int nflagged=0;
+  Vector2d<int> resultClass;
+  vector<float> user;
+  vector<float> producer;
+  vector<unsigned int> nvalidation;
+
   if(confusion_opt[0]){
     // if(class_opt.size()>1)
     //   inputRange=class_opt;
@@ -168,16 +197,6 @@ int main(int argc, char *argv[])
       for(int iclass=0;iclass<cm.nClasses();++iclass)
         cout << iclass << " " << cm.getClass(iclass) << endl;
     }
-  }
-
-  unsigned int ntotalValidation=0;
-  unsigned int nflagged=0;
-  Vector2d<int> resultClass(nclass,nclass);
-  vector<float> user(nclass);
-  vector<float> producer(nclass);
-  vector<unsigned int> nvalidation(nclass);
-
-  if(confusion_opt[0]){
     resultClass.resize(nclass,nclass);
     user.resize(nclass);
     producer.resize(nclass);
@@ -191,8 +210,8 @@ int main(int argc, char *argv[])
   }
   
   bool isDifferent=false;
-
   bool refIsRaster=false;
+
   ImgReaderOgr referenceReaderOgr;
   try{
     referenceReaderOgr.open(reference_opt[0]);
@@ -403,7 +422,7 @@ int main(int argc, char *argv[])
 		  continue;
 		if(verbose_opt[0])
 		  cout << setprecision(12) << "reading image value at x,y " << x << "," << y << " (" << i << "," << j << "), ";
-		inputReader.readData(inputValue,GDT_Int16,i,j,band_opt[0]);
+		inputReader.readData(inputValue,GDT_Float64,i,j,band_opt[0]);
 		inputValues.push_back(inputValue);
 		if(inputValues.back()!=*(inputValues.begin()))
 		  isHomogeneous=false;
@@ -416,18 +435,18 @@ int main(int argc, char *argv[])
 		    break;
 		  }
 		}
-		maskFlagged=false;//(masknodata_opt[ivalue]>=0)?false:true;
+		maskFlagged=false;//(msknodata_opt[ivalue]>=0)?false:true;
 		if(mask_opt.size()){
-		  maskReader.readData(maskValue,GDT_Int16,i,j,band_opt[0]);
-		  for(int ivalue=0;ivalue<masknodata_opt.size();++ivalue){
-		    if(masknodata_opt[ivalue]>=0){//values set in masknodata_opt are invalid
-		      if(maskValue==masknodata_opt[ivalue]){
+		  maskReader.readData(maskValue,GDT_Float64,i,j,0);
+		  for(int ivalue=0;ivalue<msknodata_opt.size();++ivalue){
+		    if(msknodata_opt[ivalue]>=0){//values set in msknodata_opt are invalid
+		      if(maskValue==msknodata_opt[ivalue]){
 			maskFlagged=true;
 			break;
 		      }
 		    }
-		    else{//only values set in masknodata_opt are valid
-		      if(maskValue!=-masknodata_opt[ivalue])
+		    else{//only values set in msknodata_opt are valid
+		      if(maskValue!=-msknodata_opt[ivalue])
 			maskFlagged=true;
 		      else{
 			maskFlagged=false;
@@ -571,11 +590,11 @@ int main(int argc, char *argv[])
       }//next reference
     }//next input
     pfnProgress(1.0,pszMessage,pProgressArg);
-  }//reference is OGR
-  else{
+  }//reference is OGR vector
+  else{//reference is GDAL raster
     ImgWriterGdal gdalWriter;
     try{
-      inputReader.open(input_opt[0]);//,imagicX_opt[0],imagicY_opt[0]);
+      inputReader.open(input_opt[0]);
       if(mask_opt.size())
         maskReader.open(mask_opt[0]);
       if(output_opt.size()){
@@ -607,15 +626,18 @@ int main(int argc, char *argv[])
       exit(2);
     }
     //todo: support different data types!
-    vector<short> lineInput(inputReader.nrOfCol());
-    vector<short> lineMask(maskReader.nrOfCol());
-    vector<short> lineOutput;
+    vector<double> lineInput(inputReader.nrOfCol());
+    vector<double> lineMask(maskReader.nrOfCol());
+    vector<double> lineOutput;
+    vector<double> bufferInput;//for regression
+    vector<double> bufferReference;//for regression
     if(output_opt.size())
       lineOutput.resize(inputReader.nrOfCol());
 
     int irow=0;
     int icol=0;
     double oldreferencerow=-1;
+    double oldmaskrow=-1;
     ImgReaderGdal referenceReaderGdal;
     try{
       referenceReaderGdal.open(reference_opt[0]);//,rmagicX_opt[0],rmagicY_opt[0]);
@@ -627,11 +649,11 @@ int main(int argc, char *argv[])
     if(inputReader.isGeoRef()){
       assert(referenceReaderGdal.isGeoRef());
       if(inputReader.getProjection()!=referenceReaderGdal.getProjection())
-        cout << "projection of input image and reference image are different!" << endl;
+        cerr << "Warning: projection of input image and reference image are different" << endl;
     }
-    vector<short> lineReference(referenceReaderGdal.nrOfCol());
+    vector<double> lineReference(referenceReaderGdal.nrOfCol());
     if(confusion_opt[0]){
-      referenceReaderGdal.getRange(referenceRange,band_opt[0]);
+      referenceReaderGdal.getRange(referenceRange,band_opt[1]);
       for(int iflag=0;iflag<nodata_opt.size();++iflag){
         vector<short>::iterator fit;
         fit=find(referenceRange.begin(),referenceRange.end(),nodata_opt[iflag]);
@@ -655,32 +677,41 @@ int main(int argc, char *argv[])
         exit(1);
       }
     }
-    for(irow=0;irow<inputReader.nrOfRow()&&!isDifferent;++irow){
+    double rmse=0;
+    // for(irow=0;irow<inputReader.nrOfRow()&&!isDifferent;++irow){
+    for(irow=0;irow<inputReader.nrOfRow();++irow){
       //read line in lineInput, lineReference and lineMask
-      inputReader.readData(lineInput,GDT_Int16,irow,band_opt[0]);
-      if(mask_opt.size())
-        maskReader.readData(lineMask,GDT_Int16,irow);
+      inputReader.readData(lineInput,GDT_Float64,irow,band_opt[0]);
       double x,y;//geo coordinates
       double ireference,jreference;//image coordinates in reference image
+      double imask,jmask;//image coordinates in mask image
       for(icol=0;icol<inputReader.nrOfCol();++icol){
         //find col in reference
         inputReader.image2geo(icol,irow,x,y);
         referenceReaderGdal.geo2image(x,y,ireference,jreference);
         if(ireference<0||ireference>=referenceReaderGdal.nrOfCol()){
-          cerr << ireference << " out of reference range!" << endl;
-          cerr << x << " " << y << " " << icol << " " << irow << endl;
-          cerr << x << " " << y << " " << ireference << " " << jreference << endl;
-          exit(1);
+	  if(rmse_opt[0]||regression_opt[0])
+	    continue;
+	  else{
+	    cerr << ireference << " out of reference range!" << endl;
+	    cerr << x << " " << y << " " << icol << " " << irow << endl;
+	    cerr << x << " " << y << " " << ireference << " " << jreference << endl;
+	    exit(1);
+	  }
         }
         if(jreference!=oldreferencerow){
           if(jreference<0||jreference>=referenceReaderGdal.nrOfRow()){
-            cerr << jreference << " out of reference range!" << endl;
-            cerr << x << " " << y << " " << icol << " " << irow << endl;
-            cerr << x << " " << y << " " << ireference << " " << jreference << endl;
-            exit(1);
+	    if(rmse_opt[0]||regression_opt[0])
+	      continue;
+	    else{
+	      cerr << jreference << " out of reference range!" << endl;
+	      cerr << x << " " << y << " " << icol << " " << irow << endl;
+	      cerr << x << " " << y << " " << ireference << " " << jreference << endl;
+	      exit(1);
+	    }
           }
           else{
-            referenceReaderGdal.readData(lineReference,GDT_Int16,static_cast<int>(jreference),band_opt[0]);
+            referenceReaderGdal.readData(lineReference,GDT_Float64,static_cast<int>(jreference),band_opt[1]);
             oldreferencerow=jreference;
           }
         }
@@ -694,14 +725,27 @@ int main(int argc, char *argv[])
           }
         }
         if(mask_opt.size()){
-          for(int ivalue=0;ivalue<masknodata_opt.size();++ivalue){
-            if(lineMask[icol]==masknodata_opt[ivalue]){
-              flagged=true;
-              break;
-            }
+	  maskReader.geo2image(x,y,imask,jmask);
+	  if(jmask>=0&&jmask<maskReader.nrOfRow()){
+	    if(jmask!=oldmaskrow)
+	      maskReader.readData(lineMask,GDT_Float64,jmask);
+	    for(int ivalue=0;ivalue<msknodata_opt.size();++ivalue){
+	      if(lineMask[icol]==msknodata_opt[ivalue]){
+		flagged=true;
+		break;
+	      }
+	    }
           }
         }
         if(!flagged){
+	  if(rmse_opt[0]){//divide by image size to prevent overflow. At the end we need to take care about flagged pixels by normalizing...
+	    rmse+=static_cast<double>(lineInput[icol]-lineReference[ireference])*(lineInput[icol]-lineReference[ireference])/inputReader.nrOfCol()/inputReader.nrOfRow();
+	  }
+	  else if(regression_opt[0]){
+	    bufferInput.push_back(lineInput[icol]);
+	    bufferReference.push_back(lineReference[ireference]);
+	  }
+
           if(confusion_opt[0]){
             ++ntotalValidation;
             int rc=distance(referenceRange.begin(),find(referenceRange.begin(),referenceRange.end(),lineReference[ireference]));
@@ -724,22 +768,11 @@ int main(int argc, char *argv[])
             }
           }
           else{//error
-            if(output_opt.empty()&&!confusion_opt[0]){
+            if(output_opt.empty()&&!confusion_opt[0]&&!rmse_opt[0]&&!regression_opt[0]){
               isDifferent=true;
               break;
             }
             if(output_opt.size()){
-              // if(lineInput[icol]<20){//forest
-              //   if(lineReference[icol]>=20)//gain
-              //     lineOutput[icol]=lineInput[icol]*10+1;//GAIN is 111,121,131
-              //   else//forest type changed: mixed
-              //     lineOutput[icol]=130;//MIXED FOREST
-              // }
-              // else if(lineReference[icol]<20){//loss
-              //   lineOutput[icol]=20*10+lineReference[icol];//LOSS is 211 212 213
-              // }
-              // else//no forest
-              //   lineOutput[icol]=20*10;//NON FOREST is 200
               if(lineInput[icol]>lineReference[ireference])
 		lineOutput[icol]=valueO_opt[0];//omission error
 	      else
@@ -759,7 +792,7 @@ int main(int argc, char *argv[])
       }
       if(output_opt.size()){
         try{
-          gdalWriter.writeData(lineOutput,GDT_Int16,irow);
+          gdalWriter.writeData(lineOutput,GDT_Float64,irow);
         }
         catch(string errorstring){
           cerr << "lineOutput.size(): " << lineOutput.size() << endl;
@@ -768,7 +801,7 @@ int main(int argc, char *argv[])
           exit(1);
         }
       }
-      else if(isDifferent&&!confusion_opt[0]){//we can break off here, files are different...
+      else if(isDifferent&&!confusion_opt[0]&&!rmse_opt[0]&&!regression_opt[0]){//we can break off here, files are different...
         if(!verbose_opt[0])
           pfnProgress(1.0,pszMessage,pProgressArg);
         break;
@@ -780,7 +813,38 @@ int main(int argc, char *argv[])
     if(output_opt.size())
       gdalWriter.close();
     else if(!confusion_opt[0]){
-      if(isDifferent)
+      if(rmse_opt[0]){
+	double normalization=1.0*inputReader.nrOfCol()*inputReader.nrOfRow()/(inputReader.nrOfCol()*inputReader.nrOfRow()-nflagged);
+	if(verbose_opt[0]){
+	  cout << "normalization: " << normalization << endl;
+	  cout << "rmse before sqrt and normalization: " << rmse << endl;
+	}
+	cout << "--rmse " << sqrt(rmse/normalization) << endl;
+      }
+      else if(regression_opt[0]){
+	double err=0;
+	double c0=0;
+	double c1=1;
+	statfactory::StatFactory stat;
+	if(bufferInput.size()&&bufferReference.size()){
+	  err=stat.linear_regression_err(bufferInput,bufferReference,c0,c1);
+	}
+	if(verbose_opt[0]){
+	  cout << "bufferInput.size(): " << bufferInput.size() << endl;
+	  cout << "bufferReference.size(): " << bufferReference.size() << endl;
+	  double theMin=0;
+	  double theMax=0;
+	  stat.minmax(bufferInput,bufferInput.begin(),bufferInput.end(),theMin,theMax);
+	  cout << "min,  max input: " << theMin << ", " << theMax << endl;
+	  theMin=0;
+	  theMax=0;
+	  stat.minmax(bufferReference,bufferReference.begin(),bufferReference.end(),theMin,theMax);
+	  cout << "min,  max reference: " << theMin << ", " << theMax << endl;
+	}
+	cout << "--c0 " << c0 << "--c1 " << c1 << " --rmse: " << err << endl;
+	
+      }
+      else if(isDifferent)
         cout << input_opt[0] << " and " << reference_opt[0] << " are different" << endl;
       else
         cout << input_opt[0] << " and " << reference_opt[0] << " are identical" << endl;
@@ -789,67 +853,9 @@ int main(int argc, char *argv[])
     inputReader.close();
     if(mask_opt.size())
       maskReader.close();
-  }
+  }//raster dataset
 
   if(confusion_opt[0]){
-    // double totalResult=0;
-    // cout << " ";
-    // for(int ic=0;ic<inputRange.size();++ic)
-    //   cout << inputRange[ic] << " ";
-    // cout << endl;
-    // unsigned int ntotal=0;
-    // vector<unsigned int> ntotalclass(referenceRange.size());
-    // for(int rc=0;rc<referenceRange.size();++rc){
-    //   ntotalclass[rc]=0;
-    //   cout << referenceRange[rc] << " ";
-    //   //initialize
-    //   for(int ic=0;ic<inputRange.size();++ic){
-    //     unsigned int result=0;
-    //     user[ic]=0;
-    //     producer[ic]=0;	
-    //     for(int k=0;k<nclass;++k){
-    //       user[ic]+=resultClass[k][ic];
-    //       producer[ic]+=resultClass[ic][k];
-    //     }	  
-    //     result=resultClass[rc][ic];
-    //     ntotal+=result;
-    //     ntotalclass[rc]+=result;
-    //     if(ic==rc){
-    //       totalResult+=result;
-    //     }
-    //     cout << result << " ";
-    //   }
-    //   cout << endl;
-    // }
-    // if(verbose_opt[0]){
-    //   cout << "totalResult: " << totalResult << endl;
-    //   cout << "ntotalValidation: " << ntotalValidation << endl;
-    //   cout << "nflagged: " << nflagged << endl;
-    //   cout << "ntotal: " << ntotal << endl;
-    // }
-    // totalResult*=100.0/ntotal;
-    // int nclass0=0;//number of classes without any reference
-    // for(int rc=0;rc<referenceRange.size();++rc)
-    //   if(!nvalidation[rc])
-    //     ++nclass0;
-    // double pChance=0;
-    // double pCorrect=0;
-    // double totalEntries=0;
-    // cout << "class #samples userAcc prodAcc" << endl;    
-    // for(int rc=0;rc<referenceRange.size();++rc){
-    //   totalEntries+=user[rc];
-    //   pChance+=user[rc]*producer[rc];
-    //   pCorrect+=resultClass[rc][rc];
-    //   cout << referenceRange[rc] << " " << nvalidation[rc] << " ";
-    //   cout << 100.0*resultClass[rc][rc]/user[rc] << " "//user accuracy
-    //        << 100.0*resultClass[rc][rc]/producer[rc] << " " << endl;//producer accuracy
-    // }
-    // pCorrect/=totalEntries;
-    // pChance/=totalEntries*totalEntries;    
-    // double kappa=pCorrect-pChance;
-    // kappa/=1-pChance;
-    // cout << "Kappa: " << kappa << endl;    
-    // cout << "total weighted: " << static_cast<int>(0.5+totalResult) << endl;
     assert(cm.nReference());
     cout << cm << endl;
     cout << "class #samples userAcc prodAcc" << endl;
